@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v a203f7207a0a 2015/01/24 16:56:09 gomor $
+# $Id: Whois.pm,v 9bb393adbc03 2015/03/11 06:47:35 gomor $
 #
 # client::whois Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a203f7207a0a $',
+      revision => '$Revision: 9bb393adbc03 $',
       tags => [ qw(unstable client whois) ],
       commands => {
          domain => [ qw(domain) ],
@@ -34,7 +34,7 @@ sub domain {
    }
 
    my $nw = Metabrik::Network::Whois->new_from_brik($self) or return;
-   my $lines = $nw->domain($domain)
+   my $lines = $nw->target($domain)
       or return $self->log->error("domain: domain failed");
 
    my %general = ();
