@@ -1,5 +1,5 @@
 #
-# $Id: Cwe.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Cwe.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # database::cwe Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Fetch);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable cve cwe) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -44,7 +44,7 @@ sub update {
    $self->get($uri, $file)
       or return $self->log->error("update: get failed");
 
-   my $file_compress = Metabrik::File::Compress->new_from_brik($self);
+   my $file_compress = Metabrik::File::Compress->new_from_brik($self) or return;
 
    $file_compress->unzip($file, $datadir)
       or return $self->log->error("update: unzip failed");
@@ -63,7 +63,7 @@ sub load {
 
    my $datadir = $self->datadir;
 
-   my $file_xml = Metabrik::File::Xml->new_from_brik($self);
+   my $file_xml = Metabrik::File::Xml->new_from_brik($self) or return;
 
    my $xml = $file_xml->read($datadir.'/'.$file);
 
