@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Countrycode.pm,v a6e30d37450c 2015/03/16 06:08:27 gomor $
 #
 # lookup::countrycode Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable iana cc) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: a6e30d37450c $',
+      tags => [ qw(unstable lookup iana countrycode cc) ],
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(file) ],
@@ -40,7 +38,9 @@ sub country_code_types {
    my $self = shift;
    my ($data) = @_;
 
-   $self->brik_help_run_undef_arg('country_code_types', $data) or return;
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('country_code_types'));
+   }
 
    my %list = ();
    for my $this (@$data) {
@@ -52,18 +52,17 @@ sub country_code_types {
    return \@types;
 }
 
-#
 # Port numbers:
 # http://www.iana.org/protocols
 # http://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.xhtml
-#
+
 sub update {
    my $self = shift;
 
    my $uri = 'http://www.iana.org/domains/root/db';
 
-   my $get = $self->get($uri) or return;
-   my $html = $get->{content};
+   my $get = $self->get($uri) or return $self->log->error("update: get failed");
+   my $html = $get->{body};
 
    # <tr class="iana-group-1 iana-type-2">
    #   <td><span class="domain tld"><a href="/domains/root/db/abogado.html">.abogado</a></span></td>
@@ -102,18 +101,21 @@ sub save {
    my $self = shift;
    my ($data, $output) = @_;
 
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('save'));
+   }
+
    $output ||= $self->output;
-   $self->brik_help_run_undef_arg('save', $data) or return;
-   $self->brik_help_run_undef_arg('save', $output) or return;
 
    my $datadir = $self->datadir;
 
-   my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
-   $fc->overwrite(1);
-   $fc->encoding('utf8');
+   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
+   $file_csv->overwrite(1);
+   $file_csv->encoding('utf8');
 
    my $output_file = $datadir.'/'.$output;
-   $fc->write($data, $output_file) or return;
+   $file_csv->write($data, $output_file)
+      or return $self->log->error("save: write failed");
 
    return $output_file;
 }
@@ -123,15 +125,16 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->input;
-   $self->brik_help_run_undef_arg('load', $input) or return;
-   $self->brik_help_run_file_not_found('load', $input) or return;
+   if (! -f $input) {
+      return $self->log->error("load: file [$input] not found");
+   }
 
    my $datadir = $self->datadir;
 
-   my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
-   $fc->first_line_is_header(1);
+   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
+   $file_csv->first_line_is_header(1);
 
-   my $csv = $fc->read($datadir.'/'.$input) or return;
+   my $csv = $file_csv->read($datadir.'/'.$input);
 
    return $csv;
 }
@@ -146,7 +149,7 @@ Metabrik::Lookup::Countrycode - lookup::countrycode Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
