@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v e9efd64d88ce 2015/02/26 06:10:35 gomor $
+# $Id: Service.pm,v 50e1856d022c 2015/03/07 11:56:23 gomor $
 #
 # lookup::service Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: e9efd64d88ce $',
+      revision => '$Revision: 50e1856d022c $',
       tags => [ qw(unstable lookup service iana) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -49,6 +49,22 @@ sub update {
    $ff->get($url, $output)
       or return $self->log->error("update: get failed");
 
+   # We have to rewrite the CSV file, cause some entries are multiline.
+   my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
+   $ft->overwrite(1);
+   $ft->append(0);
+   my $text = $ft->read($output)
+      or return $self->log->error("update: read failed");
+
+   # Some lines are split on multi-lines, we put into a single line
+   # for each record.
+   my @new = split(/\r\n/, $text);
+   for (@new) {
+      s/\n/ /g;
+   }
+
+   $ft->write(\@new, $output);
+
    return $output;
 }
 
