@@ -1,5 +1,5 @@
 #
-# $Id: Icmp.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Icmp.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # network::icmp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Frame);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable icmp ping redirect doubleredirect mitm) ],
       commands => {
          ping => [ qw(ipv4_address) ],
@@ -59,7 +59,7 @@ sub ping {
    my $frame2 = $self->frame([ $ipv4, $icmpv4, $echo2 ]);
    my $frame3 = $self->frame([ $ipv4, $icmpv4, $echo3 ]);
 
-   my $write = Metabrik::Network::Write->new_from_brik($self);
+   my $write = Metabrik::Network::Write->new_from_brik($self) or return;
 
    # We must use different Net::Frame::Simple objects so recv() method will work
    for my $f ($frame1, $frame2, $frame3) {
