@@ -1,5 +1,5 @@
 #
-# $Id: Portscan.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Portscan.pm,v b6b7ae90f8d0 2015/03/17 06:40:26 gomor $
 #
 # network::portscan Brik
 #
@@ -11,12 +11,9 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable scan syn port synscan tcpscan) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: b6b7ae90f8d0 $',
+      tags => [ qw(unstable portscan synscan tcpscan) ],
       attributes => {
-         device => [ qw(device) ],
          ports => [ qw(port_array) ],
          top10 => [ qw(top10_port_array) ],
          top100 => [ qw(top100_port_array) ],
@@ -129,7 +126,6 @@ sub brik_properties {
          'Net::Frame::Simple' => [ ],
          'Net::Frame::Dump' => [ ],
          'List::Util' => [ ],
-         'POSIX' => [ qw(ceil) ],
          'Metabrik::Network::Device' => [ ],
          'Metabrik::Network::Read' => [ ],
          'Metabrik::Network::Address' => [ ],
@@ -138,72 +134,44 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         device => $self->global->device,
-      },
-   };
-}
-
 sub tcp_syn {
    my $self = shift;
    my ($ip_list, $port_list, $pps) = @_;
 
-   $pps ||= $self->pps;
-   my $try = $self->try;
-   $self->brik_help_run_undef_arg('tcp_syn', $ip_list) or return;
-   my $refip = $self->brik_help_run_invalid_arg('tcp_syn', $ip_list, 'ARRAY', 'SCALAR')
-      or return;
+   if (! defined($ip_list)) {
+      return $self->log->error($self->brik_help_run('tcp_syn'));
+   }
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
 
-   if ($refip eq 'ARRAY') {
+   if (ref($ip_list) eq 'ARRAY') {
       if (@$ip_list == 0) {
-         return $self->log->error("tcp_syn: ARRAY Argument is empty");
-      }
-
-      # We take the ARRAY of elements (IP addresses or subnets)
-      # And convert it to an IP address list
-      my $new_list = [];
-      for my $this (@$ip_list) {
-         if ($na->is_ipv4_subnet($this)) {
-            my $list = $na->ipv4_list($this) or next;
-            push @$new_list, @$list;
-         }
-         #elsif ($na->is_ipv6_subnet($this)) { # XXX: not impl
-            #my $list = $na->ipv6_list($this) or next;
-            #push @$new_list, @$list;
-         #}
-         elsif ($na->is_ip($this)) {
-            push @$new_list, $this;
-         }
-      }
-      $ip_list = $new_list;
-   }
-   else {  # We gave a simple SCALAR
-      if ($na->is_ipv4_subnet($ip_list)) {
-         $ip_list = $na->ipv4_list($ip_list) or return;
-      }
-      #elsif ($na->is_ipv6_subnet($ip_list)) { # XXX: not impl
-         #$ip_list = $na->ipv6_list($ip_list) or return;
-      #}
-      elsif ($na->is_ip($ip_list)) {
-         $ip_list = [ $ip_list ];
-      }
-      else {
-         return $self->log->error("tcp_syn: invalid IP [$ip_list] given");
+         return $self->log->error("tcp_syn: ip_list is empty");
       }
    }
+   else {
+      if (! $na->is_ip($ip_list)) {
+         return $self->log->error("tcp_syn: argument 0 must be IP or ARRAYREF");
+      }
+      # A single IP has been provided, we put it back into an ARRAYREF
+      $ip_list = [ $ip_list ];
+   }
 
-   $port_list ||= $self->ports || $self->top100;
-   $self->brik_help_run_invalid_arg('tcp_syn', $port_list, 'ARRAY') or return;
-   $self->brik_help_run_empty_array_arg('tcp_syn', $port_list) or return;
+   $port_list ||= $self->top100;
+   if (ref($port_list) ne 'ARRAY') {
+      return $self->log->error("tcp_syn: argument 2 must be ARRAYREF");
+   }
+   if (@$port_list == 0) {
+      return $self->log->error("tcp_syn: port_list is empty");
+   }
+
+   $pps ||= $self->pps;
+
+   my $try = $self->try;
 
    my $nd = Metabrik::Network::Device->new_from_brik_init($self) or return;
-   my $get = $nd->get($self->device) or return;
+   my $get = $nd->get($self->global->device)
+      or return $self->log->error("tcp_syn: device failed");
 
    my $ip = $get->{ipv4};
    my $ip6 = $get->{ipv6};
@@ -230,7 +198,7 @@ sub tcp_syn {
    }
    $nr->filter($filter);
 
-   $nr->open or return;
+   $nr->open or return $self->log->error("tcp_syn: open failed");
 
    my $n_ports = scalar(@$port_list);
    my $n_targets = scalar(@$ip_list);
@@ -253,33 +221,17 @@ sub tcp_syn {
 
    if (! $pid) { # Son
       $self->debug && $self->log->debug("tcp_syn: son starts its task...");
-      # We have to split by chunks of 500_000 elements, to avoid taking to
-      # much memory in one row. And there is a SIGSEGV if we don't do so ;)
-      my $n_chunks = POSIX::ceil($n_targets / 500_000);
-      for my $n (0..$n_chunks-1) {
-         my $first = 500_000 * $n;
-         my $last = 499_999 + (500_000 * $n);
-         if ($last > ($n_targets - 1)) {
-            $last = $n_targets - 1;
-         }
-
-         if ($n_chunks > 1) {
-            $self->log->verbose("tcp_syn: scanning chunk @{[$n+1]}/@{[($n_chunks)]} ($first-$last)");
-         }
-
-         my @this = @$ip_list[$first..$last];
-         my $r = Net::Write::Fast::l4_send_tcp_syn_multi(
-            $use_ipv6 ? $ip6 : $ip,
-            \@this,
-            $port_list,
-            $pps,
-            $try,
-            $use_ipv6,
-            1,  # display warnings or not
-         );
-         if ($r == 0) {
-            $self->log->error("tcp_syn: l4_send_tcp_syn_multi: ".Net::Write::Fast::nwf_geterror());
-         }
+      my $r = Net::Write::Fast::l4_send_tcp_syn_multi(
+         $use_ipv6 ? $ip6 : $ip,
+         $ip_list,
+         $port_list,
+         $pps,
+         $try,
+         $use_ipv6,
+         1,  # display warnings or not
+      );
+      if ($r == 0) {
+         $self->log->error("tcp_syn: l4_send_tcp_syn_multi: ".Net::Write::Fast::nwf_geterror());
       }
       $self->debug && $self->log->debug("tcp_syn: son finished its task, exiting");
       exit(0);
@@ -289,45 +241,42 @@ sub tcp_syn {
    my %open;
    my %closed;
    while (! $nr->has_timeout) {
-      if (my $next = $nr->read_until_timeout) {
-         $self->debug && $self->log->debug("tcp_syn: read_until_timeout has some stuff");
-         for my $f (@$next) {
-            my $s = Net::Frame::Simple->newFromDump($f);
-            #printf STDERR "flags: 0x%02x\n", $s->ref->{TCP}->flags;
-            if ($s->ref->{TCP}) {
-               my $ip  = $use_ipv6 ? $s->ref->{IPv6} : $s->ref->{IPv4};
-               my $tcp = $s->ref->{TCP};
-               if ($tcp->flags == 0x12) { # SYN+ACK
-                  #print STDERR "open: [".$ip->src."]:".$tcp->src."/tcp\n";
-                  $self->log->verbose("tcp_syn: open port [".$ip->src."]:".$tcp->src."/tcp");
-                  $open{$ip->src}{$tcp->src} = {
-                     id => $use_ipv6 ? $ip->flowLabel : $ip->id,
-                     ttl => $use_ipv6 ? $ip->hopLimit  : $ip->ttl,
-                     win => $tcp->win,
-                     opt => unpack('H*', $tcp->options),
-                     flags => 'SA',
-                  };
-               }
-               elsif ($tcp->flags == 0x14) { # RST+ACK
-                  $closed{$ip->src}{$tcp->src} = {
-                     id => $use_ipv6 ? $ip->flowLabel : $ip->id,
-                     ttl => $use_ipv6 ? $ip->hopLimit  : $ip->ttl,
-                     win => $tcp->win,
-                     opt => unpack('H*', $tcp->options),
-                     flags => 'RA',
-                  };
-               }
+      if (my $f = $nr->next) {
+         my $s = Net::Frame::Simple->newFromDump($f);
+         #printf STDERR "flags: 0x%02x\n", $s->ref->{TCP}->flags;
+         if ($s->ref->{TCP}) {
+            my $ip  = $use_ipv6 ? $s->ref->{IPv6} : $s->ref->{IPv4};
+            my $tcp = $s->ref->{TCP};
+            if ($tcp->flags == 0x12) { # SYN+ACK
+               #print STDERR "open: [".$ip->src."]:".$tcp->src."/tcp\n";
+               $self->log->verbose("tcp_syn: open port [".$ip->src."]:".$tcp->src."/tcp");
+               $open{$ip->src}{$tcp->src} = {
+                  id => $use_ipv6 ? $ip->flowLabel : $ip->id,
+                  ttl => $use_ipv6 ? $ip->hopLimit  : $ip->ttl,
+                  win => $tcp->win,
+                  opt => unpack('H*', $tcp->options),
+                  flags => 'SA',
+               };
+            }
+            elsif ($tcp->flags == 0x14) { # RST+ACK
+               $closed{$ip->src}{$tcp->src} = {
+                  id => $use_ipv6 ? $ip->flowLabel : $ip->id,
+                  ttl => $use_ipv6 ? $ip->hopLimit  : $ip->ttl,
+                  win => $tcp->win,
+                  opt => unpack('H*', $tcp->options),
+                  flags => 'RA',
+               };
             }
          }
-         if ($nr->has_timeout) {
-            $self->debug && $self->log->debug("tcp_syn: has_timeout");
-            if (! $wf->is_son_alive) {
-               $self->log->verbose("tcp_syn: no more son, stopping loop");
-               last;
-            }
-            $self->debug && $self->log->debug("tcp_syn: reset_timeout");
-            $nr->reset_timeout;
+      }
+      if ($nr->has_timeout) {
+         $self->debug && $self->log->debug("tcp_syn: has_timeout");
+         if (! $wf->is_son_alive) {
+            $self->log->verbose("tcp_syn: no more son, stopping loop");
+            last;
          }
+         $self->debug && $self->log->debug("tcp_syn: reset_timeout");
+         $nr->reset_timeout;
       }
    }
    
@@ -379,7 +328,7 @@ Metabrik::Network::Portscan - network::portscan Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
