@@ -1,5 +1,5 @@
 #
-# $Id: Sinfp3.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Sinfp3.pm,v 1d19720513f5 2015/03/08 11:41:04 gomor $
 #
 # network::sinfp3 Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1d19720513f5 $',
       tags => [ qw(unstable network sinfp3 sinfp osfp fingerprint fingerprinting) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -45,6 +45,10 @@ sub active {
    my $self = shift;
    my ($target, $port) = @_;
 
+   if ($< != 0) {
+      return $self->log->error("active: must be root to run");
+   }
+
    $target ||= $self->target;
    $port ||= $self->port;
 
