@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v f86a021f7e5f 2015/01/24 17:03:49 gomor $
+# $Id: Whois.pm,v f9542919cc81 2015/02/21 10:40:01 gomor $
 #
 # network::whois Brik
 #
@@ -11,10 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f86a021f7e5f $',
+      revision => '$Revision: f9542919cc81 $',
       tags => [ qw(unstable network whois) ],
       commands => {
-         domain => [ qw(domain) ],
+         target => [ qw(domain|ip_address) ],
       },
       require_modules => {
          'Net::Whois::Raw' => [ ],
@@ -23,24 +23,20 @@ sub brik_properties {
    };
 }
 
-sub domain {
+sub target {
    my $self = shift;
-   my ($domain) = @_;
+   my ($target) = @_;
 
-   if (! defined($domain)) {
-      return $self->log->error($self->brik_help_run('domain'));
+   if (! defined($target)) {
+      return $self->log->error($self->brik_help_run('target'));
    }
 
-   if ($domain !~ /^\S+\.\S+$/) {
-      return $self->log->error("domain: invalid format for domain [$domain]");
-   }
-
-   my $info = Net::Whois::Raw::whois($domain)
-      or return $self->log->error("domain: whois failed");
+   my $info = Net::Whois::Raw::whois($target)
+      or return $self->log->error("target: whois failed");
 
    my $parse_string = Metabrik::String::Parse->new_from_brik($self) or return;
    my $lines = $parse_string->to_array($info)
-      or return $self->log->error("domain: to_array failed");
+      or return $self->log->error("target: to_array failed");
 
    return $lines;
 }
